@@ -9,8 +9,10 @@ class SamsungTV1: public PIRKeysetMetaData
 {
 public:
   SamsungTV1(
-    QObject *guiObject,
     unsigned int index);
+
+  virtual void populateProtocol(
+    QObject *guiObject);
 };
 
 
@@ -18,8 +20,10 @@ class SamsungTV1a: public SamsungTV1
 {
 public:
   SamsungTV1a(
-    QObject *guiObject,
     unsigned int index);
+
+  virtual void populateProtocol(
+    QObject *guiObject);
 };
 
 
@@ -27,8 +31,10 @@ class SamsungTV1b: public SamsungTV1
 {
 public:
   SamsungTV1b(
-    QObject *guiObject,
     unsigned int index);
+
+  virtual void populateProtocol(
+    QObject *guiObject);
 };
 
 
@@ -36,8 +42,10 @@ class SamsungTV1c: public SamsungTV1
 {
 public:
   SamsungTV1c(
-    QObject *guiObject,
     unsigned int index);
+
+  virtual void populateProtocol(
+    QObject *guiObject);
 };
 
 
@@ -45,8 +53,10 @@ class SamsungTV1d: public SamsungTV1
 {
 public:
   SamsungTV1d(
-    QObject *guiObject,
     unsigned int index);
+
+  virtual void populateProtocol(
+    QObject *guiObject);
 };
 
 
@@ -54,8 +64,10 @@ class SamsungTV1e: public SamsungTV1
 {
 public:
   SamsungTV1e(
-    QObject *guiObject,
     unsigned int index);
+
+  virtual void populateProtocol(
+    QObject *guiObject);
 };
 
 
@@ -63,8 +75,10 @@ class SamsungTV1f: public SamsungTV1
 {
 public:
   SamsungTV1f(
-    QObject *guiObject,
     unsigned int index);
+
+  virtual void populateProtocol(
+    QObject *guiObject);
 };
 
 
@@ -72,24 +86,30 @@ class SamsungTV2: public PIRKeysetMetaData
 {
 public:
   SamsungTV2(
-    QObject *guiObject,
     unsigned int index);
+
+  virtual void populateProtocol(
+    QObject *guiObject);
 };
 
 class SamsungTV2a: public SamsungTV2
 {
 public:
   SamsungTV2a(
-    QObject *guiObject,
     unsigned int index);
+
+  virtual void populateProtocol(
+    QObject *guiObject);
 };
 
 class SamsungVCR1: public PIRKeysetMetaData
 {
 public:
   SamsungVCR1(
-    QObject *guiObject,
     unsigned int index);
+
+  virtual void populateProtocol(
+    QObject *guiObject);
 };
 
 
@@ -97,88 +117,110 @@ class SamsungVCR1a: public SamsungVCR1
 {
 public:
   SamsungVCR1a(
-    QObject *guiObject,
     unsigned int index);
+
+  virtual void populateProtocol(
+    QObject *guiObject);
 };
 
 class SamsungVCR1b: public SamsungVCR1
 {
 public:
   SamsungVCR1b(
-    QObject *guiObject,
     unsigned int index);
+
+  virtual void populateProtocol(
+    QObject *guiObject);
 };
 
 class SamsungVCR1c: public SamsungVCR1a
 {
 public:
   SamsungVCR1c(
-    QObject *guiObject,
     unsigned int index);
+
+  virtual void populateProtocol(
+    QObject *guiObject);
 };
 
 class SamsungVCR1d: public SamsungVCR1
 {
 public:
   SamsungVCR1d(
-    QObject *guiObject,
     unsigned int index);
+
+  virtual void populateProtocol(
+    QObject *guiObject);
 };
 
 class SamsungVCR1e: public SamsungVCR1
 {
 public:
   SamsungVCR1e(
-    QObject *guiObject,
     unsigned int index);
+
+  virtual void populateProtocol(
+    QObject *guiObject);
 };
 
 class SamsungDVD1: public PIRKeysetMetaData
 {
 public:
   SamsungDVD1(
-    QObject *guiObject,
     unsigned int index);
+
+  virtual void populateProtocol(
+    QObject *guiObject);
 };
 
 class SamsungDVD1a: public SamsungDVD1
 {
 public:
   SamsungDVD1a(
-    QObject *guiObject,
     unsigned int index);
+
+  virtual void populateProtocol(
+    QObject *guiObject);
 };
 
 class SamsungDVD1b: public SamsungDVD1
 {
 public:
   SamsungDVD1b(
-    QObject *guiObject,
     unsigned int index);
+
+  virtual void populateProtocol(
+    QObject *guiObject);
 };
 
 class SamsungDVD2: public PIRKeysetMetaData
 {
 public:
   SamsungDVD2(
-    QObject *guiObject,
     unsigned int index);
+
+  virtual void populateProtocol(
+    QObject *guiObject);
 };
 
 class SamsungAC1: public PIRKeysetMetaData
 {
 public:
   SamsungAC1(
-    QObject *guiObject,
     unsigned int index);
+
+  virtual void populateProtocol(
+    QObject *guiObject);
 };
 
 class SamsungDVBT1: public PIRKeysetMetaData
 {
 public:
   SamsungDVBT1(
-    QObject *guiObject,
     unsigned int index);
+
+  virtual void populateProtocol(
+    QObject *guiObject);
 };
 
 #endif // SAMSUNG_H
