@@ -24,6 +24,7 @@ enum PIRMakeName{
   DigitalStream_Make,
   Directv_Make,
   Dish_Make,
+  Dreambox_Make,
   DSE_Make,
   Dynex_Make,
   Ei_Make,
@@ -32,6 +33,7 @@ enum PIRMakeName{
   Epson_Make,
   Fortec_Make,
   Foxtel_Make,
+  Genius_Make,
   GoldStar_Make,
   Grundig_Make,
   Haier_Make,
@@ -50,6 +52,7 @@ enum PIRMakeName{
   LG_Make,
   Logitech_Make,
   Magnavox_Make,
+  Magnum_Make,
   Microsoft_Make,
   Mitsubishi_Make,
   Motorola_Make,
@@ -74,6 +77,8 @@ enum PIRMakeName{
   Sony_Make,
   Starsat_Make,
   Technics_Make,
+  Telenet_Make,
+  Thomson_Make,
   Tivo_Make,
   Topfield_Make,
   Toshiba_Make,
